probnum.linalg
==============

Linear Algebra.

This package implements probabilistic numerical methods for the solution of problems
arising in linear algebra, such as the solution of linear systems.

.. automodapi:: probnum.linalg
    :no-heading:
    :no-main-docstr:
